/*
* optional_properties.js
*
* This example enumerates through search results and turns off error reporting
* for missing propertes.  Instead of getting an error value that tells us
* that the property we're asking for is either invalid or missing for a given
* result item, we just get null back since we don't really care why it's not
* there :)
*/

// The two different types of search result ranking
var RELEVANCE_RANKING = 0;
var RECENCY_RANKING = 1;  // the default

// message() borrowed from simple_query.js
function message(text) {
  WScript.Echo(text);
}

// getRegistrationCookie() borrowed from simple_query.js
function getRegistrationCookie() {
  var cookie = 0;

  try {
    var shell = new ActiveXObject("WScript.Shell");
    cookie = shell.RegRead("HKCU\\Software\\Google\\QueryAPI_Samples\\Cookie");
  } catch(e) {
    message("please run the register_script_sample.js script to register the samples");
    WScript.Quit(-1);
  }

  return cookie;
}

//
// This is the default value of error_mode
// When set GetProperty will return specific error codes that
// trigger script languages to generate and throw an error object.
//
var GDQEM_REPORT_ERRORS = 0;

//
// When the error mode is set to this value, a success code
// GetProperty will not cause an exception to be thrown but 
// rather just return null.
//
var GDQEM_REPORT_SUCCESS_WHEN_CAN_RETURN_NULL = 1

var async_query_done = false;

function displayMp3QueryResults(set) {
// Loop through the items and print out the fields that are available
  var item = null;
  var i = 0;
  while ((item = set.Next()) != null) {
    var uri = item("uri");
    var header = item("mail_header");
    var tip = item("info_tip");
    var artist = item("artist");
    var format = item("format");
    var comment = item("comment");
    var user = item("user_name");

    message(parseInt(i++) + " uri: " + uri);

    if (header != null)
      message("  mail header: " + header);

    if (tip != null)
      message("  tooltip: " + tip);

    if (artist != null)
      message("  artist: " + artist);

    if (format != null)
      message("  format: " + format);

    if (comment != null)
      message("  comment: " + comment);

    if (user != null)
      message("  im user: " + user);
  }
  message("Total results = " + i);
}

/*
* Performs a query and tries to output some fields if they're available.
* Before performing the query, we set the error_mode of the query object to
* GDQEM_REPORT_SUCCESS_WHEN_CAN_RETURN_NULL.
*/
function performQuery(search_string, max_results, with_callback) {
  var cookie = getRegistrationCookie();

  // Instantiate the main query api object
  var qapi = new ActiveXObject("GoogleDesktop.QueryAPI");

  // Initialize a query object with our query string and access cookie
  var q = qapi.QueryEx(cookie, search_string);

  //
  // Turn off error reporting for fetching property values that might
  // not be set.
  //
  q.SetOption("error_mode", GDQEM_REPORT_SUCCESS_WHEN_CAN_RETURN_NULL);
  q.SetOption("max_result_items", max_results);
  
  if (!with_callback) {
    // Execute the query
    var set = q.Execute();
    displayMp3QueryResults(set);  
  } else {
    var set = q.PrepareResultSet();
    set.onreadystatechange = onReadyStateChange;
    q.Execute();
        
    function onReadyStateChange() {
      message(set.readystate);
      displayMp3QueryResults(set);
      async_query_done = true;
    }  
  }
}

// run an arbitrary query
performQuery("mp3", 3, false);
performQuery("mp3", 3, true);
while (!async_query_done) {
   WScript.Sleep (1000);
} 